import { ofType } from 'redux-observable';
import { of } from 'rxjs';
import { switchMap, catchError, ignoreElements } from 'rxjs/operators/index.js';
import { LOCATION_CHANGE } from '@common-stack/remix-router-redux';
import { matchRoutes } from '@adminide-stack/platform-client';
import { get } from 'lodash-es';
import { IClientContainerService } from '@adminide-stack/extension-api';
import { createController } from '../extensions/controller.js';
import { PlatformContext } from '../platform/context.js';

const isBrowser = typeof document !== 'undefined';
const onLocationChangedToLoadExtEpic = (action$, state$, {
  apolloClient,
  routes,
  services,
  container
}) => action$.pipe(ofType(LOCATION_CHANGE), switchMap(route => {
  if (!container.isBound(IClientContainerService.ExtensionController) && isBrowser) {
    const branches = matchRoutes(routes, route.payload.location.pathname);
    if (branches) {
      const params = get(branches, 'params');
      if (params) {
        if (params.orgName) {
          return services.lifecycleService.when(3 /* LifecyclePhase.Restored */).then(() => {
            const pltContext = new PlatformContext(apolloClient, state$, services);
            // check again
            if (!container.isBound(IClientContainerService.ExtensionController)) {
              const __extension_controler__ = createController(pltContext, services);
              container.bind(IClientContainerService.ExtensionController).toConstantValue(__extension_controler__);
              return of({
                type: 'EXT_LOADED'
              });
            }
            return of({
              type: 'EXT_ALREADY_LOADED'
            });
          });
        }
      }
    }
  }
  return isBrowser ? of({
    type: 'EXT_ALREADY_LOADED'
  }) : of({
    type: 'EXT_NOT_LOADED'
  });
}), catchError(error => {
  // Log the error or perform other side effects
  console.error(error, 'Error in onLocationChangedToLoadExtEpic:');
  // Return a new observable, e.g., an error action
  // Replace 'EXT_LOAD_ERROR' with your actual error action type
  return of({
    type: '@platform/LOG_APPLICATION_ERROR',
    payload: {
      type: '@platform/LOAD_EXNTSION_ERROR',
      payload: error
    }
  });
}), ignoreElements());

export { onLocationChangedToLoadExtEpic };
//# sourceMappingURL=load-extension-script.js.map
